pub struct LocalStream {
w: Sender<Result<Vec<u8>>>,
r: Receiver<Result<Vec<u8>>>,
pending_bytes: Vec<u8>,
pub(crate) tls_cert: Option<Vec<u8>>,
}Expand description
One half of a pair of linked streams returned by stream_pair.
Fields
w: Sender<Result<Vec<u8>>>The writing side of the channel that we use to implement this stream.
The reading side is held by the other linked stream.
r: Receiver<Result<Vec<u8>>>The reading side of the channel that we use to implement this stream.
The writing side is held by the other linked stream.
pending_bytes: Vec<u8>Bytes that we have read from r but not yet delivered.
tls_cert: Option<Vec<u8>>Data about the other side of this stream’s fake TLS certificate, if any. If this is present, I/O operations will fail with an error.
How this is intended to work: things that return LocalStreams that could potentially
be connected to a fake TLS listener should set this field. Then, a fake TLS wrapper
type would clear this field (after checking its contents are as expected).
FIXME(eta): this is a bit of a layering violation, but it’s hard to do otherwise
Implementations
Sourceimpl LocalStream
impl LocalStream
Sourcepub async fn send_err(&mut self, kind: ErrorKind)
pub async fn send_err(&mut self, kind: ErrorKind)
Send an error to the other linked local stream.
When the other stream reads this message, it will generate a
std::io::Error with the provided ErrorKind.