struct State {
core: MockTimeCore,
futures: DenseSlotMap<DefaultKey, Option<Waker>>,
unready: PriorityQueue<DefaultKey, Reverse<Instant>>,
}Expand description
Mutable state for a Provider
Each sleep (Id, SleepFuture) is in one of the following states:
| state | SleepFuture | futures | unready |
|---|---|---|---|
| UNPOLLED | exists | present, None | present, > now |
| WAITING | exists | present, Some | present, > now |
| READY | exists | present, None | absent |
| DROPPED | dropped | absent | absent |
Fields
core: MockTimeCoreCurrent time (coarse)
futures: DenseSlotMap<DefaultKey, Option<Waker>>Futures; record of every existing SleepFuture, including any Waker
Entry exists iff SleepFuture exists.
Contains None if we haven’t polled the future;
Some if we have.
We could use a Vec or TiVec
but using a slotmap is more robust against bugs here.
unready: PriorityQueue<DefaultKey, Reverse<Instant>>Priority queue
Subset of futures.
An entry is present iff the Instant is strictly after State.now,
in which case that’s when the future should be woken.
PriorityQueue is a max-heap but we want earliest times, hence Reverse
Implementations