enum TaskFutureInfo {
Normal(FutureObj<'static, ()>),
Main,
Subthread,
}Expand description
A future as stored in our record of a Task
Variants
Normal(FutureObj<'static, ()>)
The Future. All is normal.
Main
The future isn’t here because this task is the main future for block_on
Subthread
This task is actually a Subthread
Instead of polling it, we’ll switch to it with
thread_context_switch.