struct DebugTasks<'d, F>(&'d Data, F);Expand description
Helper: Debugs as a list of tasks, given the Data for lookups and a list of the ids
Tasks in Data are printed as Ti(ID)"SPEC"=FLAGS".
FLAGS are:
-
T: this task is for a Subthread (from subthread_spawn). -
P: this task is being polled (itsTaskFutureInfois absent) -
f: this is a normal task with a future and its future is present inData -
m: this is the main task fromblock_on -
W: the task is awake -
s<n>: the task is asleep, and<n>is the number of recorded sleeping locations
Tuple Fields
0: &'d Data1: FTrait Implementations