struct ProgressingUntilStalled {
finished: Poll<()>,
waker: Option<Waker>,
}Expand description
State used for an in-progress call to
progress_until_stalled
If present in Data, an (async) call to progress_until_stalled
is in progress.
The future from progress_until_stalled, ProgressUntilStalledFuture
is a normal-ish future.
It can be polled in the normal way.
When it is polled, it looks here, in finished, to see if it’s Ready.
The future is made ready, and woken (via waker),
by bespoke code in the task executor loop.
When ProgressUntilStalledFuture (maybe completes and) is dropped,
its Drop impl is used to remove this from Data.progressing_until_stalled.
Fields
finished: Poll<()>Have we, in fact, stalled?
Made Ready by special code in the executor loop
waker: Option<Waker>Waker
Signalled by special code in the executor loop