struct Task {
desc: String,
state: TaskState,
fut: Option<TaskFutureInfo>,
}Expand description
Record of a single task
Tracks a spawned task, or the main task (the argument to block_on).
Stored in Data.tasks.
Fields
desc: StringFor debugging output
state: TaskStateHas this been woken via a waker? (And is it in Data.awake?)
Set to Awake only by Task::set_awake,
preserving the invariant that
every Awake task is in Data.awake.
fut: Option<TaskFutureInfo>The actual future (or a placeholder for it)
May be None briefly in the executor main loop, because we’ve
temporarily moved it out so we can poll it,
or if this is a Subthread task which is currently running sync code
(in which case we’re blocked in the executor waiting to be
woken up by thread_context_switch.
Note that the None can be observed outside the main loop, because
the main loop unlocks while it polls, so other (non-main-loop) code
might see it.
Implementations