#[repr(transparent)]pub(super) struct Ti(KeyData);Expand description
Task ID, usually called TaskId
Short name in special task_id module so that Debug is nice
Tuple Fields
0: KeyDataTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Ti
impl<'de> Deserialize<'de> for Ti
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Key for Ti
impl Key for Ti
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for Ti
impl Ord for Ti
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Ti
impl PartialOrd for Ti
impl Copy for Ti
impl Eq for Ti
impl StructuralPartialEq for Ti