trait EnsureSyncSend:
Sync
+ Send
+ 'static { }Expand description
Trait to let us assert at compile time that something is nicely Sync etc.
trait EnsureSyncSend:
Sync
+ Send
+ 'static { }Trait to let us assert at compile time that something is nicely Sync etc.