struct SleepEntry {
when: Instant,
waker: Waker,
}Expand description
An entry telling us when to wake which future up.
Fields
when: InstantThe time at which this entry should wake
waker: WakerThe Waker to call when the instant has passed.