pub(crate) trait TlsProvider<S>:
Clone
+ Send
+ Sync
+ 'staticwhere
S: StreamOps,{
type Connector: TlsConnector<S, Conn = Self::TlsStream> + Send + Sync + Unpin;
type TlsStream: AsyncRead + AsyncWrite + StreamOps + CertifiedConn + Unpin + Send + 'static;
type Acceptor: TlsConnector<S, Conn = Self::TlsServerStream> + Send + Sync + Unpin;
type TlsServerStream: AsyncRead + AsyncWrite + StreamOps + CertifiedConn + Unpin + Send + 'static;
// Required methods
fn tls_connector(&self) -> Self::Connector;
fn tls_acceptor(
&self,
settings: TlsAcceptorSettings,
) -> Result<Self::Acceptor, Error>;
fn supports_keying_material_export(&self) -> bool;
}Expand description
Trait for a runtime that knows how to create TLS connections over
TCP streams of type S.
This is separate from TlsConnector because eventually we may
eventually want to support multiple TlsConnector implementations
that use a single Runtime.
See the TlsConnector documentation for a discussion of the Tor-specific
limitations of this trait: If you are implementing something other than Tor,
this is not the functionality you want.
Required Associated Types
Sourcetype Connector: TlsConnector<S, Conn = Self::TlsStream> + Send + Sync + Unpin
type Connector: TlsConnector<S, Conn = Self::TlsStream> + Send + Sync + Unpin
The Connector object that this provider can return.
Sourcetype TlsStream: AsyncRead + AsyncWrite + StreamOps + CertifiedConn + Unpin + Send + 'static
type TlsStream: AsyncRead + AsyncWrite + StreamOps + CertifiedConn + Unpin + Send + 'static
The type of the stream returned by that connector.
Sourcetype Acceptor: TlsConnector<S, Conn = Self::TlsServerStream> + Send + Sync + Unpin
type Acceptor: TlsConnector<S, Conn = Self::TlsServerStream> + Send + Sync + Unpin
The Acceptor object that this provider can return, for handling incoming connections.
Sourcetype TlsServerStream: AsyncRead + AsyncWrite + StreamOps + CertifiedConn + Unpin + Send + 'static
type TlsServerStream: AsyncRead + AsyncWrite + StreamOps + CertifiedConn + Unpin + Send + 'static
The type of stream returned by that Acceptor.
Required Methods
Sourcefn tls_connector(&self) -> Self::Connector
fn tls_connector(&self) -> Self::Connector
Return a TLS connector for use with this runtime.
Sourcefn tls_acceptor(
&self,
settings: TlsAcceptorSettings,
) -> Result<Self::Acceptor, Error>
fn tls_acceptor( &self, settings: TlsAcceptorSettings, ) -> Result<Self::Acceptor, Error>
Return a TLS acceptor for use with this runtime.
Not every TlsProvider supports this method.
For those that do, this method is only supported
when tor-rtcompat is built with the tls-server feature.
When this method is unsupported, it returns an error.
Sourcefn supports_keying_material_export(&self) -> bool
fn supports_keying_material_export(&self) -> bool
Return true iff the keying material exporters (RFC 5705) is supported.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.