type SleepLocation = Backtrace;Expand description
We record “where a future went to sleep” as (just) a backtrace
This type alias allows us to mock Backtrace for miri.
(It also insulates from future choices about sleep location representation.0
Aliased Type
struct SleepLocation { /* private fields */ }