pub(crate) struct MockCoarseTimeProvider {
started: CoarseInstant,
elapsed: Duration,
}Expand description
A mockable CoarseTimeProvider
Fields
started: CoarseInstantStarting point
elapsed: DurationHow much we have advanced
We track this as a Duration, not a CoarseDuration (or CoarseInstant)
to avoid accumulating rounding errors,
which might otherwise cause the mocked Instant and CoarseInstant
clocks to run at noticeably different rates.
Implementations